[syslinux:pathbased] isolinux: 7C00h -> TEXT_START

syslinux-bot for H. Peter Anvin hpa at zytor.com
Wed Feb 24 18:39:02 PST 2010


Commit-ID:  f9fb542ed74650f25e21c48e966b40b761c64589
Gitweb:     http://syslinux.zytor.com/commit/f9fb542ed74650f25e21c48e966b40b761c64589
Author:     H. Peter Anvin <hpa at zytor.com>
AuthorDate: Wed, 24 Feb 2010 18:38:17 -0800
Committer:  H. Peter Anvin <hpa at zytor.com>
CommitDate: Wed, 24 Feb 2010 18:38:17 -0800

isolinux: 7C00h -> TEXT_START

Use the TEXT_START macro instead of hard-coding 7C00h.

Signed-off-by: H. Peter Anvin <hpa at zytor.com>


---
 core/isolinux.asm |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/core/isolinux.asm b/core/isolinux.asm
index 837c619..078f7ca 100644
--- a/core/isolinux.asm
+++ b/core/isolinux.asm
@@ -411,12 +411,12 @@ found_file:
 		; Load the rest of the file.  However, just in case there
 		; are still BIOSes with 64K wraparound problems, we have to
 		; take some extra precautions.  Since the normal load
 		; address (7C00h) is *not* 2K-sector-aligned, we round
 		; the target address upward to a sector boundary,
 		; and then move the entire thing down as a unit.
 MaxLMA		equ 384*1024		; Reasonable limit (384K)
 
-		mov bx,((7C00h+2*SECTOR_SIZE-1) & ~(SECTOR_SIZE-1)) >> 4
+		mov bx,((TEXT_START+2*SECTOR_SIZE-1) & ~(SECTOR_SIZE-1)) >> 4
 		mov bp,[ImageSectors]
 		push bx			; Load segment address
 
@@ -452,7 +452,7 @@ MaxLMA		equ 384*1024		; Reasonable limit (384K)
 		; Move the image into place, and also verify the
 		; checksum
 		pop ax				; Load segment address
-		mov bx,(7C00h + SECTOR_SIZE) >> 4
+		mov bx,(TEXT_START + SECTOR_SIZE) >> 4
 		mov ecx,[ImageDwords]
 		mov edi,[FirstSecSum]		; First sector checksum
 		xor si,si
@@ -411,12 +411,12 @@ found_file:
 		; are still BIOSes with 64K wraparound problems, we have to
 		; take some extra precautions.  Since the normal load
-		; address (7C00h) is *not* 2K-sector-aligned, we round
+		; address (TEXT_START) is *not* 2K-sector-aligned, we round
 		; the target address upward to a sector boundary,
 		; and then move the entire thing down as a unit.



More information about the Syslinux-commits mailing list